==> Sisimai-4.19.0.tar.gz: Sisimai-4.19.0/set-of-emails/maildir/bsd/README.md <==
About Sample Emails in set-of-emails/maildir/bsd Directory
===========================================================

Sisimai::ARF
------------
* arf-14.eml
  * [FBL-auth.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/FBL-auth.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

* arf-15.eml
  * [fbl-hotmail.txt](https://github.com/prasad83/node-bounce-handler/blob/master/eml/fbl-hotmail.txt)
  * Copyright (c) 2014 prasad83 | The MIT License

Sisimai::MTA::Exchange2003
--------------------------
* exchange-06.eml
  * mailman-2.1.15/tests/bounces/groupwise_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::Exchange2007
--------------------------
* exchange2007-02.eml
  * [message-too-large.msg](https://github.com/rjbs/Mail-DeliveryStatus-BounceParser/blob/master/t/corpus/message-too-large.msg)
  * Copyright (C) 2003-2006 IC Group, Inc. | GPLv2

* exchange2007-03.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-mail-box-full.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

Sisimai::MTA::Exim
------------------
* exim-09.eml
  * [13.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/13.eml)
  * Copyright (c) 2014 prasad83 | The MIT License

* exim-10.eml
  * [34.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/34.eml)
  * Copyright (c) 2014 prasad83 | The MIT License

* exim-11.eml
  * [44.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/44.eml)
  * Copyright (c) 2014 prasad83 | The MIT License

* exim-12.eml
  * [0224.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0224.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-13.eml
  * [0237.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0237.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-14.eml
  * [9001.CALLER](https://github.com/Exim/exim/blob/master/test/mail/9001.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-15.eml
  * [0536.oksender](https://github.com/Exim/exim/blob/master/test/mail/0536.oksender)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-16.eml
  * [0522.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0522.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-17.eml
  * [0310.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0310.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-18.eml
  * [0280.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0280.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-19.eml
  * [0174.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0174.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-20.eml
  * [0531.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0531.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-21.eml
  * [0461.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0461.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-22.eml
  * [0321.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0321.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-23.eml
  * [0253.lmn](https://github.com/Exim/exim/blob/master/test/mail/0253.lmn)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-24.eml
  * [0136.forwarder](https://github.com/Exim/exim/blob/master/test/mail/0136.forwarder)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-25.eml
  * [0233.me](https://github.com/Exim/exim/blob/master/test/mail/0233.me)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-26.eml
  * [0015.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0015.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-27.eml
  * [0211.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0211.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* exim-28.eml
  * [0226.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0226.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

Sisimai::MTA::IMailServer
-------------------------
* imailserver-05.eml
  * mailman-2.1.15/tests/bounces/smtp32_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::InterScanMSS
--------------------------
* interscanmss-02.eml
  * mailman-2.1.15/tests/bounces/simple_15.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::Notes
-------------------
* notes-04.eml
  * [msg00154.html](http://osdir.com/ml/org.telecom.india-gii/2003-02/msg00154.html)
  * Copyrighted (c) 2000-2015, but we're happy to let you use what you wish with attribution. OSDir.com

Sisimai::MTA::Postfix
---------------------
* postfix-18.eml
  * [relay_failed.eml](https://github.com/choonkeat/deliveryboy/blob/master/spec/fixtures/bounce_cases/relay_failed.eml)
  * Copyright (c) 2011 Chew Choon Keat | The MIT License

* postfix-19.eml
  * [testfile.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/testfile.eml)
  * Copyright (c) 2011 Chew Choon Keat | The MIT License

* postfix-20.eml
  * mailman-2.1.15/tests/bounces/postfix_05.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* postfix-22.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce_400.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* postfix-23.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce_500.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* postfix-24.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-invalid-address.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* postfix-25.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-smtp-timeout.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* postfix-26.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-unknown_domain.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* postfix-27.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_postfix_non_existing_mailbox.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

Sisimai::MTA::qmail
-------------------
* qmail-09.eml
  * mailman-2.1.15/tests/bounces/qmail_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* qmail-10.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_qmail_extra_lines_between_recipient_paragraphs.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

* qmail-11.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_qmail_multipart_alternative_non_existing_mailbox.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

* qmail-12.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_qmail_no_host_found.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

Sisimai::RFC3464
----------------
* rfc3464-10.eml
  * [DSN-bounce.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/DSN-bounce.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

* rfc3464-11.eml
  * [NDR-block.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/NDR-block.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

* rfc3464-12.eml
  * mailman-2.1.15/tests/bounces/dsn_17.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-13.eml
  * mailman-2.1.15/tests/bounces/dsn_08.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-14.eml
  * mailman-2.1.15/tests/bounces/dsn_07.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-15.eml
  * mailman-2.1.15/tests/bounces/dsn_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-16.eml
  * mailman-2.1.15/tests/bounces/bounce_02.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-17.eml
  * mailman-2.1.15/tests/bounces/bounce_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-18.eml
  * mailman-2.1.15/tests/bounces/dsn_14.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-19.eml
  * mailman-2.1.15/tests/bounces/microsoft_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-20.eml
  * mailman-2.1.15/tests/bounces/postfix_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-21.eml
  * mailman-2.1.15/tests/bounces/sendmail_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-24.eml
  * mailman-2.1.15/tests/bounces/simple_24.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-30.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-over-quota.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

Sisimai::RFC3834
----------------
* rfc3834-01.eml
  * [out_of_office.eml](https://github.com/tangofoxtrot/tmail_bouncer/blob/master/test/fixtures/out_of_office.eml)
  * Copyright (c) 2009 tangofoxtrot | The MIT License

* rfc3834-02.eml
  * [warning-6.msg](https://github.com/rjbs/Mail-DeliveryStatus-BounceParser/blob/master/t/corpus/warning-6.msg)
  * Copyright (C) 2003-2006 IC Group, Inc. | GPLv2

* rfc3834-03.eml
  * [aol-vacation.msg](https://github.com/rjbs/Mail-DeliveryStatus-BounceParser/blob/master/t/corpus/aol-vacation.msg)
  * Copyright (C) 2003-2006 IC Group, Inc. | GPLv2

* rfc3834-04.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-invalid2.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* rfc3834-05.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-invalid3.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

Sisimai::MTA::Sendmail
----------------------
* sendmail-23.eml
  * [DSN-spam.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/DSN-spam.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

Sisimai::MSP::US::Google
------------------------
* us-google-12.eml
  * mailman-2.1.15/tests/bounces/simple_17.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* us-google-13.eml
  * mailman-2.1.15/tests/bounces/simple_28.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MSP::US::Outlook
-------------------------
* us-outlook-09.eml
  * [connection_timed_out.eml](https://github.com/choonkeat/deliveryboy/blob/master/spec/fixtures/bounce_cases/connection_timed_out.eml)
  * Copyright (c) 2011 Chew Choon Keat | The MIT License

Sisimai::MTA::X2
----------------
* x2-05.eml
  * mailman-2.1.15/tests/bounces/yahoo_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::X4
----------------
* x4-01.eml
  * [bounce-secureservers.net-mailfolder_is_full.eml](https://github.com/justingit/dada-mail/blob/master/dada/t/corpus/email_messages/bounce-secureservers.net-mailfolder_is_full.eml)
  * Copyright (c) 1999 - 2015 Justin Simoni | GPL

* x4-02.eml
  * mailman-2.1.15/tests/bounces/newmailru_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* x4-03.eml
  * mailman-2.1.15/tests/bounces/qmail_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* x4-04.eml
  * mailman-2.1.15/tests/bounces/qmail_04.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* x4-05.eml
  * mailman-2.1.15/tests/bounces/qmail_05.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* x4-06.eml
  * mailman-2.1.15/tests/bounces/qmail_06.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

==> Sisimai-4.20.0.tar.gz: Sisimai-4.20.0/set-of-emails/maildir/bsd/README.md <==
About Sample Emails in set-of-emails/maildir/bsd Directory
===========================================================

Sisimai::ARF
------------
* arf-14.eml
  * [FBL-auth.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/FBL-auth.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

* arf-15.eml
  * [fbl-hotmail.txt](https://github.com/prasad83/node-bounce-handler/blob/master/eml/fbl-hotmail.txt)
  * Copyright (c) 2014 prasad83 | The MIT License

Sisimai::MTA::Exchange2003
--------------------------
* mta-exchange-06.eml
  * mailman-2.1.15/tests/bounces/groupwise_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::Exchange2007
--------------------------
* mta-exchange2007-02.eml
  * [message-too-large.msg](https://github.com/rjbs/Mail-DeliveryStatus-BounceParser/blob/master/t/corpus/message-too-large.msg)
  * Copyright (C) 2003-2006 IC Group, Inc. | GPLv2

* mta-exchange2007-03.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-mail-box-full.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

Sisimai::MTA::Exim
------------------
* mta-exim-09.eml
  * [13.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/13.eml)
  * Copyright (c) 2014 prasad83 | The MIT License

* mta-exim-10.eml
  * [34.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/34.eml)
  * Copyright (c) 2014 prasad83 | The MIT License

* mta-exim-11.eml
  * [44.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/44.eml)
  * Copyright (c) 2014 prasad83 | The MIT License

* mta-exim-12.eml
  * [0224.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0224.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-13.eml
  * [0237.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0237.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-14.eml
  * [9001.CALLER](https://github.com/Exim/exim/blob/master/test/mail/9001.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-15.eml
  * [0536.oksender](https://github.com/Exim/exim/blob/master/test/mail/0536.oksender)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-16.eml
  * [0522.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0522.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-17.eml
  * [0310.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0310.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-18.eml
  * [0280.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0280.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-19.eml
  * [0174.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0174.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-20.eml
  * [0531.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0531.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-21.eml
  * [0461.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0461.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-22.eml
  * [0321.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0321.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-23.eml
  * [0253.lmn](https://github.com/Exim/exim/blob/master/test/mail/0253.lmn)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-24.eml
  * [0136.forwarder](https://github.com/Exim/exim/blob/master/test/mail/0136.forwarder)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-25.eml
  * [0233.me](https://github.com/Exim/exim/blob/master/test/mail/0233.me)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-26.eml
  * [0015.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0015.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-27.eml
  * [0211.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0211.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

* mta-exim-28.eml
  * [0226.CALLER](https://github.com/Exim/exim/blob/master/test/mail/0226.CALLER)
  * Copyright (c) 1995 - 2012 University of Cambridge.

Sisimai::MTA::IMailServer
-------------------------
* mta-imailserver-05.eml
  * mailman-2.1.15/tests/bounces/smtp32_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::InterScanMSS
--------------------------
* mta-interscanmss-02.eml
  * mailman-2.1.15/tests/bounces/simple_15.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::Notes
-------------------
* mta-notes-04.eml
  * [msg00154.html](http://osdir.com/ml/org.telecom.india-gii/2003-02/msg00154.html)
  * Copyrighted (c) 2000-2015, but we're happy to let you use what you wish with attribution. OSDir.com

Sisimai::MTA::Postfix
---------------------
* mta-postfix-18.eml
  * [relay_failed.eml](https://github.com/choonkeat/deliveryboy/blob/master/spec/fixtures/bounce_cases/relay_failed.eml)
  * Copyright (c) 2011 Chew Choon Keat | The MIT License

* mta-postfix-19.eml
  * [testfile.eml](https://github.com/prasad83/node-bounce-handler/blob/master/eml/testfile.eml)
  * Copyright (c) 2011 Chew Choon Keat | The MIT License

* mta-postfix-20.eml
  * mailman-2.1.15/tests/bounces/postfix_05.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* mta-postfix-22.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce_400.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* mta-postfix-23.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce_500.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* mta-postfix-24.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-invalid-address.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* mta-postfix-25.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-smtp-timeout.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* mta-postfix-26.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-unknown_domain.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* mta-postfix-27.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_postfix_non_existing_mailbox.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

Sisimai::MTA::qmail
-------------------
* mta-qmail-09.eml
  * mailman-2.1.15/tests/bounces/qmail_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* mta-qmail-10.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_qmail_extra_lines_between_recipient_paragraphs.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

* mta-qmail-11.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_qmail_multipart_alternative_non_existing_mailbox.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

* mta-qmail-12.eml
  * https://github.com/rgl/MailBounceDetector/blob/master/MailBounceDetector.Tests/Fixtures/bounce_qmail_no_host_found.eml
  * Copyright (c) 2015 Rui Lopes (ruilopes.com) | MIT

Sisimai::RFC3464
----------------
* rfc3464-10.eml
  * [DSN-bounce.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/DSN-bounce.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

* rfc3464-11.eml
  * [NDR-block.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/NDR-block.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

* rfc3464-12.eml
  * mailman-2.1.15/tests/bounces/dsn_17.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-13.eml
  * mailman-2.1.15/tests/bounces/dsn_08.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-14.eml
  * mailman-2.1.15/tests/bounces/dsn_07.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-15.eml
  * mailman-2.1.15/tests/bounces/dsn_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-16.eml
  * mailman-2.1.15/tests/bounces/bounce_02.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-17.eml
  * mailman-2.1.15/tests/bounces/bounce_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-18.eml
  * mailman-2.1.15/tests/bounces/dsn_14.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-19.eml
  * mailman-2.1.15/tests/bounces/microsoft_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-20.eml
  * mailman-2.1.15/tests/bounces/postfix_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-21.eml
  * mailman-2.1.15/tests/bounces/sendmail_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-24.eml
  * mailman-2.1.15/tests/bounces/simple_24.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* rfc3464-30.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-over-quota.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

Sisimai::RFC3834
----------------
* rfc3834-01.eml
  * [out_of_office.eml](https://github.com/tangofoxtrot/tmail_bouncer/blob/master/test/fixtures/out_of_office.eml)
  * Copyright (c) 2009 tangofoxtrot | The MIT License

* rfc3834-02.eml
  * [warning-6.msg](https://github.com/rjbs/Mail-DeliveryStatus-BounceParser/blob/master/t/corpus/warning-6.msg)
  * Copyright (C) 2003-2006 IC Group, Inc. | GPLv2

* rfc3834-03.eml
  * [aol-vacation.msg](https://github.com/rjbs/Mail-DeliveryStatus-BounceParser/blob/master/t/corpus/aol-vacation.msg)
  * Copyright (C) 2003-2006 IC Group, Inc. | GPLv2

* rfc3834-04.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-invalid2.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

* rfc3834-05.eml
  * https://github.com/LoneStarInternet/mail_manager/tree/master/spec/test_app/spec/support/files/bounce-invalid3.txt
  * Copyright (c) 2015 Lone Star Internet, Inc. | MIT

Sisimai::MTA::Sendmail
----------------------
* mta-sendmail-23.eml
  * [DSN-spam.eml](https://github.com/sendgrid/go-gmime/blob/master/gmime/fixtures/DSN-spam.eml)
  * Copyright (c) 2014, 2015 SendGrid Inc. | The MIT License

Sisimai::MSP::US::Google
------------------------
* us-msp-google-12.eml
  * mailman-2.1.15/tests/bounces/simple_17.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* us-msp-google-13.eml
  * mailman-2.1.15/tests/bounces/simple_28.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MSP::US::Outlook
-------------------------
* us-msp-outlook-09.eml
  * [connection_timed_out.eml](https://github.com/choonkeat/deliveryboy/blob/master/spec/fixtures/bounce_cases/connection_timed_out.eml)
  * Copyright (c) 2011 Chew Choon Keat | The MIT License

Sisimai::MTA::X2
----------------
* mta-x2-05.eml
  * mailman-2.1.15/tests/bounces/yahoo_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

Sisimai::MTA::X4
----------------
* mta-x4-01.eml
  * [bounce-secureservers.net-mailfolder_is_full.eml](https://github.com/justingit/dada-mail/blob/master/dada/t/corpus/email_messages/bounce-secureservers.net-mailfolder_is_full.eml)
  * Copyright (c) 1999 - 2015 Justin Simoni | GPL

* mta-x4-02.eml
  * mailman-2.1.15/tests/bounces/newmailru_01.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* mta-x4-03.eml
  * mailman-2.1.15/tests/bounces/qmail_03.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* mta-x4-04.eml
  * mailman-2.1.15/tests/bounces/qmail_04.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* mta-x4-05.eml
  * mailman-2.1.15/tests/bounces/qmail_05.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2

* mta-x4-06.eml
  * mailman-2.1.15/tests/bounces/qmail_06.txt
  * Copyright (C) 1989, 1991 Free Software Foundation, Inc. | GPLv2
